## [Sequential testing](http://stats.stackexchange.com/questions/23295/sequential-testing)

Here is some quick and dirty code for carrying out multiple t-tests over a fake dataset. There may be more elegant way of doing this, but that should let you started with R in a simple way. This solution *assumes* that the 20 samples are independent.


    # Simulate some data
    dfrm <- replicate(20, rnorm(1e6))
    colnames(dfrm) <- paste("V", 1:20, sep="")
    
    # Add random signal 
    inc <- sample(1:20, 3)
    dfrm[,inc] <- dfrm[,inc]+.5
    
    # Setup testing framework (each combination of variables)
    idx <- combn(20, 2)
    pval <- numeric(ncol(idx))
    for (i in 1:ncol(idx))
      pval[i] <- t.test(dfrm[,idx[1,i]], dfrm[,idx[2,i]])$p.value
    
    # No. significant test at 5%
    sum(pval<.05)
    
    # All variables that were found associated
    colnames(dfrm)[unique(as.vector(idx[,pval<.05]))]
    
    # Pretty print as table (well, a data.frame; but it can be exported 
    # as LaTeX with the xtable package.)
    res <- data.frame(t(idx[,pval<.05]), p=pval[pval<.05])
    res$X1 <- colnames(dfrm)[res$X1]
    res$X2 <- colnames(dfrm)[res$X2]
    
    # After Bonferroni correction
    res$padj <- p.adjust(res$p, method="bonf")
    res[res$padj<.05,]

I only reported variable names and associated p-values (with and without correction for multiple tests), but you can add extra information in the `for` loop (e.g., $t$ value, dof, etc.). Please note that R uses Welch's t-test as the default. See `help(t.test)` to use classical Student t-test instead. Sample results look like

    > res
       X1  X2           p      padj
    1  V1  V4 0.000000000 0.0000000
    2  V1  V5 0.000000000 0.0000000
    3  V1  V7 0.000000000 0.0000000
    4  V2  V4 0.000000000 0.0000000
    5  V2  V5 0.000000000 0.0000000
    6  V2  V7 0.000000000 0.0000000
    7  V3  V4 0.000000000 0.0000000
    8  V3  V5 0.000000000 0.0000000
    9  V3  V6 0.009132565 0.5296888
    10 V3  V7 0.000000000 0.0000000
    11 V3  V9 0.014075639 0.8163871

If all variables are numerical, and data were collected on the same sample, you need a paired t-test (`paired=TRUE`) but why not using simple correlation tests directly? (Simply replace `t.test()` with `cor.test()` in the testing loop.)

